@@ -24,19 +24,39 @@ except Exception as e:
 
 def jsonToFormat(format, response):
     if len(response) < 100 and 'error' in response:
-        response = '{}'
+        response = None
     if format == Enumerations.Format.Json:
+        if response is None:
+            return '{"Error": "There has been an internal error processing the request!"}'
         return response
     elif format == Enumerations.Format.Dictionary:
+        if response is None:
+            return {'Error': 'There has been an internal error processing the request!'}
         return json.loads(response)
     elif format == Enumerations.Format.DataFrame:
-        return jsonToDataFrame(response)
+        if response is None:
+            scenario = 'Pacifico'
+            datePublicationAux = datetime.date.today()
+            dateEffectiveAux = datetime.datetime.now()
+            country = Enumerations.Country.Country_Unspecified
+            market = ''
+            group = ''
+            family = ''
+            ticker = 'Error'
+            value = ''
+            field = Enumerations.FieldType.Field_Unspecified
+            dateTenor = datePublicationAux
+            other = 'There has been an internal error processing the request!'
+            dataFrameData = [scenario, datePublicationAux, dateEffectiveAux, country, market, group, family, ticker, value, field, dateTenor, other]
+            return pandas.DataFrame(dataFrameData, columns=['Scenario', 'Date Publication', 'Date Effective', 'Country', 'Market', 'Group', 'Family', 'Ticker', 'Value', 'Field', 'Date Tenor', 'Other'])
+
+    return jsonToDataFrame(response)
 
 def jsonToDataFrame(jsonString):
     # Is a json value
     isJsonValue = '"field"' in jsonString
     # Is a json Report
-    isJsonReport = '"variant"' in jsonString or '/bfi/input/reports' in jsonString or jsonString == '{}'
+    isJsonReport = '"variant"' in jsonString or '/bfi/input/reports' in jsonString or jsonString is None
     if isJsonValue:
         return jsonValuesToDataFrame(jsonString)
     elif isJsonReport:
@@ -46,7 +66,7 @@ def jsonToDataFrame(jsonString):
 
 def jsonReportsToDataFrame(jsonString):
     try:
-        _jsonReportsToDataFrame(jsonString)
+        return _jsonReportsToDataFrame(jsonString)
     except:
         dataFrameData = []
         author = 'Pacifico'
@@ -77,12 +97,17 @@ def _jsonReportsToDataFrame(jsonString):
     dataFrameData = []
     firstBrowser = True
     windowCount = 0
-    if '/bfi/input/reports' in jsonString:
-        reports = parseRawReports(jsonString)
-        awsAccessKey = None
-        awsSecretKey = None
-        jsonString = ioDataPointReport.DataPointReportFromMessageReport(reports, awsAccessKey, awsSecretKey)
     data = json.loads(jsonString)
+    # Pre processed
+    if isinstance(data, list):  # C++ response
+        try:  # Could be just a very big response
+            reports = parseRawReports(data)
+            awsAccessKey = None
+            awsSecretKey = None
+            jsonString = ioDataPointReport.DataPointReportFromMessageReport(reports, awsAccessKey, awsSecretKey)
+            data = json.loads(jsonString)
+        except:
+            pass
     if isinstance(data, list):  # Response is too big, over 5000 reports
         # print('Large response received, parsing...', end='')
         author = data[0]
@@ -174,7 +199,7 @@ def _jsonReportsToDataFrame(jsonString):
 
 def jsonValuesToDataFrame(jsonString):
     try:
-        _jsonValuesToDataFrame(jsonString)
+        return _jsonValuesToDataFrame(jsonString)
     except:
         dataFrameData = []
         scenario = 'Pacifico'
@@ -233,18 +258,26 @@ def _jsonValuesToDataFrame(jsonString):
                                         dataFrameData.append([scenario, datePublicationAux, dateEffectiveAux, country, market, group, family, ticker, value, field, dateTenor, other])
     return pandas.DataFrame(dataFrameData, columns=['Scenario', 'Date Publication', 'Date Effective', 'Country', 'Market', 'Group', 'Family', 'Ticker', 'Value', 'Field', 'Date Tenor', 'Other'])
 
-def parseRawReports(reportsJson):
-    loadedResponse = json.loads(reportsJson)
+def parseRawReports(reportsJson, loaded=True):
+    if loaded:
+        loadedResponse = reportsJson
+    else:
+        loadedResponse = json.loads(reportsJson)
     reports = []
-    if isinstance(loadedResponse, dict):
-        for key, item in loadedResponse.items():
-            if '.json' in key:
-                reportsRaw = json.loads(item)
-                for reportRaw in reportsRaw:
-                    report = Message.Report.fromJson(reportRaw)
-                    reports.append(report)
-    elif isinstance(loadedResponse, list):
-        for reportRaw in loadedResponse:
+    # if isinstance(loadedResponse, dict):
+    #     for key, item in loadedResponse.items():
+    #         if '.json' in key:
+    #             reportsRaw = json.loads(item)
+    #             for reportRaw in reportsRaw:
+    #                 report = Message.Report.fromJson(reportRaw)
+    #                 reports.append(report)
+    # elif isinstance(loadedResponse, list):
+    for reportRaw in loadedResponse:
+        if isinstance(reportRaw, list):
+            for innerReportRaw in reportRaw:
+                report = Message.Report.fromJson(innerReportRaw)
+                reports.append(report)
+        else:
             report = Message.Report.fromJson(reportRaw)
             reports.append(report)
     return reports
