@@ -108,15 +108,17 @@ def roundToSeconds(dateTime):
 
 if __name__=='__main__':
     now = datetime.datetime.now()
-    # today = datetime.date.today()
-    # print('now:', now, ' - ', dateTimeToJulian(now))
-    # print('today:', today, ' - ', dateToJulian(today))
+    todayMidDay = datetime.datetime(now.year, now.month, now.day) + datetime.timedelta(hours=12)
+    today = datetime.date.today()
+    print('now:', now, ' - ', dateTimeToJulian(now))
+    print('today (mid day):', todayMidDay, ' - ', dateTimeToJulian(todayMidDay))
+    print('today:', today, ' - ', dateToJulian(today))
     # somedate = datetime.date(2017, 5, 5)
     # print('somedate:', somedate, ' - ', dateToJulian(somedate))
     # print('somejulian:', julianToDateTime(2459355.306034731))
-    print('test:', julianToDateTime(2459684.0996975345))
-    print(now)
-    x = getExcelDate(now)
-    print(x)
-    y = getDatetimeFromExcel(x)
-    print(y)
+    print('test:', julianToDateTime(2459926.1779433936))
+    # print(now)
+    # x = getExcelDate(now)
+    # print(x)
+    # y = getDatetimeFromExcel(x)
+    # print(y)
